The road network file is a json file that is built using the osmnx package.

You can find an example of building a road network [here](https://github.com/NREL/hive/blob/main/examples/download_road_network.py)

```{note}
If this file is not specified, the model uses a euclidean style graph where vehicles travel in straight lines between the origin and destination
```
